@@ -3,11 +3,11 @@
 # @Time    : 2021/4/30 11:46
 from typing import Optional, List, Any, Union, Dict
 
-from pydantic import BaseModel, AnyUrl, Field
+from pydantic import BaseModel, Field
 
 
 class ExternalDocumentation(BaseModel):
-    url: AnyUrl
+    url: str
     description: Optional[str] = None
 
 
